import fsPromises from 'fs/promises';
import fs from 'fs';
import path from 'path';
class DefaultStateManager {
    dataDir;
    constructor(dataDir) {
        this.dataDir = dataDir;
    }
    async containsState(key) {
        const filePath = path.resolve(this.dataDir, `${key}.json`);
        if (fs.existsSync(filePath)) {
            return Promise.resolve(true);
        }
        else {
            return Promise.resolve(false);
        }
    }
    async load(key) {
        const filePath = path.resolve(this.dataDir, `${key}.json`);
        if (fs.existsSync(filePath)) {
            const data = await fsPromises.readFile(filePath, { encoding: 'utf-8' });
            try {
                return JSON.parse(data);
            }
            catch (e) {
                return Promise.reject('Failed to parse JSON for filePath: ' + filePath + '\n' + e);
            }
        }
        else {
            return Promise.reject('State not found for key: ' + key);
        }
    }
    async save(key, state) {
        const filePath = path.resolve(this.dataDir, `${key}.json`);
        await fsPromises.mkdir(path.dirname(filePath), { recursive: true });
        return fsPromises.writeFile(filePath, JSON.stringify(state, null, 2));
    }
}
export function createStateManager(dataDir) {
    return new DefaultStateManager(dataDir);
}
